local mod = ...

-- Asset
mod:registerAssetId("models/Chandler2.fbx/Prefab/ChandlerPart", "PREFAB_CHANDLER2")
mod:registerAssetId("models/Chandler2.fbx/Prefab/CounterPart", "PREFAB_CHANDLERCOUNTER")



-- Construction Asset
mod:registerAssetId("models/Chandler2.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_CHANDLER2")



-- Building Asset Processor
mod:registerAssetProcessor("models/Chandler2.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Collider Platform (climbable mesh)  -------------------------------------------------------------------------------------
-- mod:configurePrefabFlagList("models/Chandler1.fbx/Prefab/ChandlerPart", { "PLATFORM" })



-- Grounding
mod:registerPrefabComponent("models/Chandler2.fbx/Prefab/ChandlerPart/Oven.001", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Chandler2.fbx/Prefab/ChandlerPart/Bucket.001", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/Chandler2.fbx/Prefab/CounterPart/Table.001", {DataType = "COMP_GROUNDED"})



-- Resource Type: Chandler
mod:registerEnumValue( "RESOURCE_TYPE", "CHANDLER_RESOURCE_TYPE" )



-- Resource: Candles -------------------------------------------------------------------------------------
mod:registerAssetId("icons/Candle.png", "ICON_CANDLE")

mod:register({
	DataType = "RESOURCE",
	Id = "CANDLE_RESOURCE",
	ResourceName = "CANDLE_RESOURCE_NAME",
	Icon = "ICON_CANDLE",
	ResourceTypeList = { "GOODS", "CHANDLER_RESOURCE_TYPE" },
	IsTradable = true,
	ResourceLayoutType = "CRATES",
	VillagerBuyingPrice = { Resource = "GOLD", Quantity = 2 },
	DisplayInInventory = true
})



-- Job -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "CHANDLER_JOB",
	JobName = "CHANDLER_JOB_NAME",
	JobDescription = "CHANDLER_JOB_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 50.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
			-- LeftHandObject = {
			-- 	Model = "PREFAB_TOOL_FARMER_SEED_BAG", 
			-- 	WorkAttachName = "SeedBag_Anchor", 
			-- 	WalkAttachName = "SeedBag_Anchor"
			-- },
		IdleAnimation = "BAKERY"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "CHANDLER_JOB"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "CHANDLER_JOB"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "CHANDLER_JOB"
    }
})

-- mod:override({
--     Id = "CITIZEN",
--     CompatibleJobList = {
--         Action = "APPEND",
--         "CHANDLER_JOB"
--     }
-- })



-- Building Function: Chandler -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
	Id = "CHANDLER_FUNCTION",
    Name = "CHANDLER_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "CHANDLER_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
	InputInventoryCapacity = {
		{ Resource = "WOOD", Quantity = 25 },
		{ Resource = "TALLOW_RESOURCE", Quantity = 25 },
	},
    ResourceListNeeded = {
		{ Resource = "WOOD", Quantity = 1 },
		{ Resource = "TALLOW_RESOURCE", Quantity = 1 },
	},
	ResourceProduced = {
		{ Resource = "CANDLE_RESOURCE", Quantity = 2 },
	}

})



-- Building Function: Sales Counter -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_MARKET",
    Id = "CHANDLERCOUNTER_FUNCTION",
    Name = "CHANDLERCOUNTER_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "MARKET_TENDER", 
        Behavior = "BEHAVIOR_WORK"
    },
	TypeList = { "CHANDLER_RESOURCE_TYPE" },
	IsOverrideCapacity = true,
	CapacityPerSlot = 50,
	InputInventoryCapacity = {
		{ Resource = "CANDLE_RESOURCE", Quantity = 25 },
	},
    ResourceListNeeded = {
		{ Resource = "CANDLE_RESOURCE", Quantity = 5 },
	},
	ResourceProduced = {
		{ Resource = "CANDLE_RESOURCE", Quantity = 5 },
	}
})



-- Building: Chandlery ------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING", 
	Id = "CHANDLER",
	Name = "CHANDLER_NAME",
	Description = "CHANDLER_DESC",
	BuildingType = "GENERAL",
	AssetCoreBuildingPart = "CHANDLER2_PART",
	BuildingPartSetList = {
		{
			Name = "CHANDLER_SET1_NAME",
			BuildingPartList = { 
				"CHANDLER2_PART",
			}
		},
		{
			Name = "CHANDLER_SET2_NAME",
			BuildingPartList = { 
				"CHANDLER_COUNTER_PART",
			}
		}
	},	
	RequiredPartList = {
		{ Category = "CORE", Min = 1, Max = 1 }
	},
	VillagerRequired = { Status = "SERF", Quantity = 35 },
	IsEditable = true
})



-- Building Part: Core -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "CHANDLER2_PART",
	Name = "CHANDLER2_PART_NAME", 
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_CHANDLER2"
	},
	ConstructionVisual = "PREFAB_CONSTR_CHANDLER2",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {5.5, 3.75}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "CHANDLER_FUNCTION",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 25 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 10 } },
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 10 },
            { Resource = "TOOL", Quantity = 2 },
		}
	},
	DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "SUBSTRACT",
		Radius = 20.0,
		Value = 0.5
	} }
})



-- Building Part: Sales Counter -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "CHANDLER_COUNTER_PART",
	Name = "CHANDLER_COUNTER_PART_NAME", 
	Category = "COUNTER",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_CHANDLERCOUNTER"
	},
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {2, 1.5}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "CHANDLERCOUNTER_FUNCTION",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 5 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 1 } },
		RessourcesNeeded = {
            { Resource = "PLANK", Quantity = 2 }
		}
	},
	DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "ADD",
		Radius = 15.0,
		Value = 0.5
	} }
})


